Class: Animation | Chart.js
Description: Open source HTML5 Charts for your website

# # Class: Animation

## # Constructors

### # constructor

• new Animation(`cfg`, `target`, `prop`, `to?`)

#### # Parameters

Name | Type
--- | ---
`cfg` | `AnyObject`
`target` | `AnyObject`
`prop` | `string`
`to?` | `unknown`

#### # Defined in

animation.d.ts:5
(opens new window)

## # Methods

### # active

▸ active(): `boolean`

#### # Returns

`boolean`

#### # Defined in

animation.d.ts:6
(opens new window)

### # cancel

▸ cancel(): `void`

#### # Returns

`void`

#### # Defined in

animation.d.ts:8
(opens new window)

### # tick

▸ tick(`date`): `void`

#### # Parameters

Name | Type
--- | ---
`date` | `number`

#### # Returns

`void`

#### # Defined in

animation.d.ts:9
(opens new window)

### # update

▸ update(`cfg`, `to`, `date`): `void`

#### # Parameters

Name | Type
--- | ---
`cfg` | `AnyObject`
`to` | `unknown`
`date` | `number`

#### # Returns

`void`

#### # Defined in

animation.d.ts:7
(opens new window)